summaryrefslogtreecommitdiff
path: root/src/comp.c
diff options
context:
space:
mode:
authorAndrea Corallo <akrl@sdf.org>2021-05-06 16:28:43 +0200
committerAndrea Corallo <akrl@sdf.org>2021-05-06 17:16:09 +0200
commitfbbcbed10ee89e0865bbddc6683ff626ec488ee9 (patch)
treede3873d00945fc514f6bf525f4ecea9206622ce4 /src/comp.c
parent901ce566037b27233b907a51a9cbd330c77830ba (diff)
Rename comp-eln-load-path → native-comp-eln-load-path
* src/comp.c (Fcomp_el_to_eln_filename): Rename comp-eln-load-path → native-comp-eln-load-path. * src/lread.c (maybe_swap_for_eln): Likewise. * lisp/startup.el (native-comp-eln-load-path) (normal-top-level): Likewise. * lisp/emacs-lisp/comp.el (comp-spill-lap-function, comp-final) (comp-eln-load-path-eff, comp-trampoline-compile) (comp-clean-up-stale-eln, comp-run-async-workers) (comp-lookup-eln, batch-byte-native-compile-for-bootstrap): Likewise.
Diffstat (limited to 'src/comp.c')
-rw-r--r--src/comp.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/comp.c b/src/comp.c
index 5cf94762a92..5128755bf18 100644
--- a/src/comp.c
+++ b/src/comp.c
@@ -4095,11 +4095,11 @@ directory in `comp-eln-load-path' otherwise. */)
Lisp_Object source_filename = filename;
filename = Fcomp_el_to_eln_rel_filename (filename);
/* If base_dir was not specified search inside Vcomp_eln_load_path
for the first directory where we have write access. */
if (NILP (base_dir))
{
- Lisp_Object eln_load_paths = Vcomp_eln_load_path;
+ Lisp_Object eln_load_paths = Vnative_comp_eln_load_path;
FOR_EACH_TAIL (eln_load_paths)
{
Lisp_Object dir = XCAR (eln_load_paths);
@@ -4630,7 +4630,7 @@ void
eln_load_path_final_clean_up (void)
{
#ifdef WINDOWSNT
- Lisp_Object dir_tail = Vcomp_eln_load_path;
+ Lisp_Object dir_tail = Vnative_comp_eln_load_path;
FOR_EACH_TAIL (dir_tail)
{
Lisp_Object files_in_dir =
@@ -4755,7 +4755,7 @@ void
fixup_eln_load_path (Lisp_Object eln_filename)
{
Lisp_Object last_cell = Qnil;
- Lisp_Object tem = Vcomp_eln_load_path;
+ Lisp_Object tem = Vnative_comp_eln_load_path;
FOR_EACH_TAIL (tem)
if (CONSP (tem))
last_cell = tem;
@@ -5127,7 +5127,7 @@ static bool
file_in_eln_sys_dir (Lisp_Object filename)
{
Lisp_Object eln_sys_dir = Qnil;
- Lisp_Object tmp = Vcomp_eln_load_path;
+ Lisp_Object tmp = Vnative_comp_eln_load_path;
FOR_EACH_TAIL (tmp)
eln_sys_dir = XCAR (tmp);
return !NILP (Fstring_match (Fregexp_quote (Fexpand_file_name (eln_sys_dir,
@@ -5369,7 +5369,7 @@ For internal use. */);
doc: /* Hash table eln-filename -> el-filename. */);
Vcomp_eln_to_el_h = CALLN (Fmake_hash_table, QCtest, Qequal);
- DEFVAR_LISP ("comp-eln-load-path", Vcomp_eln_load_path,
+ DEFVAR_LISP ("native-comp-eln-load-path", Vnative_comp_eln_load_path,
doc: /* List of eln cache directories.
If a directory is non absolute is assumed to be relative to
@@ -5381,7 +5381,7 @@ The last directory of this list is assumed to be the system one. */);
/* Temporary value in use for bootstrap. We can't do better as
`invocation-directory' is still unset, will be fixed up during
dump reload. */
- Vcomp_eln_load_path = Fcons (build_string ("../native-lisp/"), Qnil);
+ Vnative_comp_eln_load_path = Fcons (build_string ("../native-lisp/"), Qnil);
DEFVAR_BOOL ("comp-enable-subr-trampolines", comp_enable_subr_trampolines,
doc: /* If non-nil enable primitive trampoline synthesis.
@@ -4095,11 +4095,11 @@ directory in `comp-eln-load-path' otherwise. */)
Lisp_Object source_filename = filename;
filename = Fcomp_el_to_eln_rel_filename (filename);
- /* If base_dir was not specified search inside Vcomp_eln_load_path
+ /* If base_dir was not specified search inside Vnative_comp_eln_load_path
for the first directory where we have write access. */
if (NILP (base_dir))